@@ -139,8 +139,8 @@ class GUI(Tk):
 	def dump_config(self):
 		if not hasattr(self,'data'):
 			return
-		fileout = os.path.join(self.cfg['save_path'],self.cfg['file_out'])+'_cfg.p'
-		pickle.dump(self.cfg,open(fileout, "wb"))
+		file_out = os.path.join(self.cfg['save_path'],self.cfg['file_out'])+'_cfg.p'
+		pickle.dump(self.cfg,open(file_out, "wb"))
 	
 	def load_config(self,filein=None):
 		if filein is None:
@@ -341,6 +341,9 @@ class GUI(Tk):
 			else:
 				print('Cannot do this - no dataset has been loaded.')
 				return
+		if not self.display and self.cfg['save_path'] is not None:
+			print('cfg["save_path"] is empty - please provide one!')
+			return
 		if not self.display:
 			self.process_H_W()
 		self.make_keys() # Just in case
@@ -433,6 +436,9 @@ class GUI(Tk):
 			else:
 				print('Cannot do this - no dataset has been loaded.')
 				return
+		if not self.display and self.cfg['save_path'] is not None:
+			print('cfg["save_path"] is empty - please provide one!')
+			return
 		if not self.display:
 			self.process_H_W()
 		if self.display:
@@ -460,6 +466,9 @@ class GUI(Tk):
 			else:
 				print('Cannot do this - no dataset has been loaded.')
 				return
+		if not self.display and self.cfg['save_path'] is not None:
+			print('cfg["save_path"] is empty - please provide one!')
+			return
 		fn = os.path.join(self.cfg['save_path'],self.cfg['file_out'])
 		cmd = 'ffmpeg -y -i {} -i {} -c:v copy -c:a aac {}'.format(fn+'.mp4',fn+'.wav',fn+'_AV.mp4')
 		os.system(cmd)
